# Conformational_Analysis


Conformational Analysis; Conformational Families


## Installation
Run the following to install:
'''python
pip install omolab_conf_analysis
'''

## Usage
####In your own python file

import ConformationalAnalysis

test1 = ConformationalAnalysis()

####In command line (not working yet; soon!)

mGenerate_Conf_Analysis

## Authors
Created by OMOLAB

Property of Matthew Nwerem, MS and O. Maduka Ogba, PhD   
https://madukaogba.com/
